@@ -2,7 +2,7 @@ package PICA::Writer::XML;
 use strict;
 use warnings;
 
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 
 use Scalar::Util qw(reftype);
 use XML::Writer;
@@ -27,7 +27,7 @@ sub write_record {
     my $i = 0;
     my $pica_sort = sub {
         my $f = shift;
-        my $oc  = ($f->[1] eq '') ? '00' : $f->[1];
+        my $oc  = (!defined $f->[1] or $f->[1] eq '') ? '00' : $f->[1];
         $oc = ($f->[0] eq '101@') ? ++$i . $oc : $i . $oc;
         return [$oc.$f->[0], $f];
     };
